@@ -23,12 +23,7 @@
 #include "config.h"
 #include <gnome.h>
 
-#ifdef USING_OAF
-#include <liboaf/liboaf.h>
-#include <bonobo.h>
-#else
 #include <libgnorba/gnorba.h>
-#endif
 
 #include "orbit_daemon_glue.h"
 #include "queue_io.h"
@@ -2042,17 +2037,6 @@ gpilotd_corba_quit(void)
 	CORBA_ORB_shutdown(orb, CORBA_FALSE, &ev);
 }
 
-#ifdef USING_OAF
-static ORBit_MessageValidationResult
-accept_all_cookies (CORBA_unsigned_long request_id,
-		    CORBA_Principal *principal,
-		    CORBA_char *operation)
-{
-        /* allow ALL cookies */
-	return ORBIT_MESSAGE_ALLOW_ALL;
-}
-#endif
-
 void gpilotd_corba_init(int *argc, 
 			char **argv,
 			GPilotContext **context)
@@ -2061,24 +2045,17 @@ void gpilotd_corba_init(int *argc,
 	PortableServer_POA the_poa;
 	GNOME_Pilot_Daemon acc;
 	static gboolean object_initialised = FALSE;
-#ifdef USING_OAF
-	OAF_RegistrationResult result;
-#endif
+
 	if ( object_initialised ) return;
 
 	object_initialised = TRUE;
 
 	CORBA_exception_init(&ev);
 
-#ifdef USING_OAF
-	orb = oaf_init (*argc, argv);
-	ORBit_set_request_validation_handler (accept_all_cookies);
-#else
 	orb = gnome_CORBA_init(PACKAGE,VERSION,
 			       argc,argv,
 			       GNORBA_INIT_SERVER_FUNC,&ev);
 	g_return_if_fail(ev._major == CORBA_NO_EXCEPTION);
-#endif
 
 	*context = gpilot_context_new();
 	gpilot_context_init_user (*context);
@@ -2100,26 +2077,6 @@ void gpilotd_corba_init(int *argc,
 	g_return_if_fail(ev._major == CORBA_NO_EXCEPTION);
 
 	g_message ("Activating CORBA server");
-#ifdef USING_OAF
-	result = oaf_active_server_register (
-              "OAFIID:gpilotd:a40c417b-21db-4959-a58e-40096a0daf09",
-	      CORBA_OBJECT (acc));
-	g_message ("oaf_active_server_register = %d", result);
-	switch (result) {
-	case OAF_REG_SUCCESS:
-		break;
-	case OAF_REG_NOT_LISTED:
-		g_message ("Cannot register gpilotd because not listed");
-		exit (1);
-	case OAF_REG_ALREADY_ACTIVE:
-		g_message ("Cannot register gpilotd because already active");
-		exit (0);
-	case OAF_REG_ERROR:
-	default:
-		g_message ("Cannot register gpilotd because we suck");
-		exit (1);
-	}
-#else 
 	switch(goad_server_register(CORBA_OBJECT_NIL,acc,"gpilotd","object",&ev)) {
 	case -2:
                 /* FIXME: better handling here */
@@ -2133,21 +2090,12 @@ void gpilotd_corba_init(int *argc,
 		break;
 	}
 	g_return_if_fail(ev._major == CORBA_NO_EXCEPTION);
-#endif	
 
 	CORBA_Object_release(acc, &ev);
 	g_return_if_fail(ev._major == CORBA_NO_EXCEPTION);
 
 	ORBit_custom_run_setup(orb, &ev);
 	g_return_if_fail(ev._major == CORBA_NO_EXCEPTION);
-
-#ifdef USING_OAF
-	if (!bonobo_init (CORBA_OBJECT_NIL, CORBA_OBJECT_NIL,
-			  CORBA_OBJECT_NIL)) {
-		g_message ("init_bonobo(): could not initialize Bonobo");
-		exit (EXIT_FAILURE);
-	}
-#endif
 }
 
 
